searchData={"items":[{"type":"task","title":"mix rustler_precompiled.download","doc":"A task responsible for downloading the precompiled NIFs for a given module.\n\nThis task must only be used by package creators who want to ship the\nprecompiled NIFs. The goal is to download the precompiled packages and\ngenerate a checksum to check-in alongside the project in the the Hex repository.\nThis is done by passing the `--all` flag.\n\nYou can also use the `--only-local` flag to download only the precompiled\npackage for use during development.\n\nYou can use the `--ignore-unavailable` flag to ignore any NIFs that are not available.\nThis is useful when you are developing a new NIF that does not support all platforms.\n\nThis task also accept the `--print` flag to print the checksums.\n\nSince v0.7.2 we configure the app invoking this mix task by default. This means that\nthe app you are invoking this task from will be compiled and run the \"release\" configuration.\nWe need to compile the app to make sure the module name is correct.\nTo avoid that, use the `--no-config` flag.","ref":"Mix.Tasks.RustlerPrecompiled.Download.html"},{"type":"module","title":"RustlerPrecompiled","doc":"Download and use precompiled NIFs safely with checksums.\n\nRustler Precompiled is a tool for library maintainers that rely on Rustler.\nIt helps by removing the need to have the Rust compiler installed in the\nuser's machine.\n\nCheck the [Precompilation Guide](PRECOMPILATION_GUIDE.md) for details.","ref":"RustlerPrecompiled.html"},{"type":"module","title":"Example - RustlerPrecompiled","doc":"defmodule MyApp.MyNative do\n      use RustlerPrecompiled,\n        otp_app: :my_app,\n        crate: \"my_app_nif\",\n        base_url: \"https://github.com/me/my_project/releases/download/v0.1.0\",\n        version: \"0.1.0\"\n    end","ref":"RustlerPrecompiled.html#module-example"},{"type":"module","title":"Options - RustlerPrecompiled","doc":"* `:otp_app` - The OTP app name that the dynamic library will be loaded from.\n\n  * `:crate` - The name of Rust crate if different from the `:otp_app`. This is optional.\n\n  * `:base_url` - Location where to find the NIFs from. This should be one of the following:\n\n    * A URL to a directory containing the NIFs. The name of the NIF will be appended to it\n      and a GET request will be made. Works well with public GitHub releases.\n\n    * A tuple of `{URL, headers}`. The headers should be a list of key-value pairs.\n      This is useful when the NIFs are hosted in a private server.\n\n    * A tuple of `{module, function}` where the `function` is an atom representing the function\n      name in that module. It's expected a function of arity 1, where the NIF file name is given,\n      and it should return a URL or a tuple of `{URL, headers}`.\n      This should be used for all cases not covered by the above.\n      For example when multiple requests have to be made, like when using a private GitHub release\n      through the GitHub API, or when the URLs don't resemble a simple directory.\n\n  * `:version` - The version of precompiled assets (it is part of the NIF filename).\n\n  * `:force_build` - Force the build with `Rustler`. This is `false` by default, but\n    if your `:version` is a pre-release (like \"2.1.0-dev\"), this option will always\n    be set `true`.\n    You can also configure this option by setting an application env like this:\n\n        config :rustler_precompiled, :force_build, your_otp_app: true\n\n    It is important to add the \":rustler\" package to your dependencies in order to force\n    the build. To do that, just add it to your `mix.exs` file:\n\n        {:rustler, \">= 0.0.0\", optional: true}\n\n    In case you want to force the build for all packages using RustlerPrecompiled, you\n    can set the application config `:force_build_all`, or the env var\n    `RUSTLER_PRECOMPILED_FORCE_BUILD_ALL` (see details below):\n\n        config :rustler_precompiled, force_build_all: true\n\n  * `:targets` - A list of targets [supported by\n    Rust](https://doc.rust-lang.org/rustc/platform-support.html) for which\n    precompiled assets are available. By default the following targets are\n    configured:\n\n      - `aarch64-apple-darwin`\n    - `aarch64-unknown-linux-gnu`\n    - `aarch64-unknown-linux-musl`\n    - `arm-unknown-linux-gnueabihf`\n    - `riscv64gc-unknown-linux-gnu`\n    - `x86_64-apple-darwin`\n    - `x86_64-pc-windows-gnu`\n    - `x86_64-pc-windows-msvc`\n    - `x86_64-unknown-linux-gnu`\n    - `x86_64-unknown-linux-musl`\n\n  * `:nif_versions` - A list of OTP NIF versions for which precompiled assets are\n    available. A NIF version is usually compatible with two OTP minor versions, and an older\n    NIF is usually compatible with newer OTPs. The available versions are the following:\n\n    * `2.14` - for OTP 21 and above.\n    * `2.15` - for OTP 22 and above.\n    * `2.16` - for OTP 24 and above.\n    * `2.17` - for OTP 26 and above.\n\n    By default the following NIF versions are configured:\n\n      - `2.15`\n\n    Check the compatibiliy table between Elixir and OTP in:\n    https://hexdocs.pm/elixir/compatibility-and-deprecations.html#compatibility-between-elixir-and-erlang-otp\n\n  * `:max_retries` - The maximum of retries before giving up. Defaults to `3`.\n    Retries can be disabled with `0`.\n\n  * `:variants` - A map with alternative versions of a given target. This is useful to\n    support specific versions of dependencies, such as an old glibc version, or to support\n    restrict CPU features, like AVX on x86_64.\n\n    The order of variants matters, because the first one that returns `true` is going to be\n    selected. Example:\n\n        %{\"x86_64-unknown-linux-gnu\" => [old_glibc: fn _config -> has_old_glibc?() end]}\n\nIn case \"force build\" is used, all options except the ones use by RustlerPrecompiled\nare going to be passed down to `Rustler`.\nSo if you need to configure the build, check the `Rustler` options.","ref":"RustlerPrecompiled.html#module-options"},{"type":"module","title":"Environment variables - RustlerPrecompiled","doc":"This project reads some system environment variables. They are all optional, but they\ncan change the behaviour of this library at **compile time** of your project.\n\nThey are:\n\n  * `HTTP_PROXY` or `http_proxy` - Sets the HTTP proxy configuration.\n\n  * `HTTPS_PROXY` or `https_proxy` - Sets the HTTPS proxy configuration.\n\n  * `MIX_XDG` - If present, sets the OS as `:linux` for the `:filename.basedir/3` when getting\n    an user cache dir.\n\n  * `TARGET_ARCH` - The CPU target architecture. This is useful for when building your Nerves\n    project, where your host CPU is different from your target CPU.\n\n    Note that Nerves sets this value automatically when building your project.\n\n    Examples: `arm`, `aarch64`, `x86_64`, `riscv64`.\n\n  * `TARGET_ABI` - The target ABI (e.g., `gnueabihf`, `musl`). This is set by Nerves as well.\n\n  * `TARGET_VENDOR` - The target vendor (e.g., `unknown`, `apple`, `pc`). This is **not** set by Nerves.\n    If any of the `TARGET_` env vars is set, but `TARGET_VENDOR` is empty, then we change the\n    target vendor to `unknown` that is the default value for Linux systems.\n\n  * `TARGET_OS` - The target operational system. This is always `linux` for Nerves.\n\n  * `RUSTLER_PRECOMPILED_GLOBAL_CACHE_PATH` - The global cache path directory. If set, it will ignore\n    the default cache path resolution, thus ignoring `MIX_XDG`, and will try to fetch the artifacts\n    from that path. In case the desired artifact is not found, a download is going to start.\n\n    This variable is important for systems that cannot perform a download at compile time, like inside\n    NixOS. It will require people to previously download the artifacts to that path.\n\n  * `RUSTLER_PRECOMPILED_FORCE_BUILD_ALL` - If set to \"1\" or \"true\", it will override the `:force_build`\n    configuration for all packages, and will force the build for them all.\n    You can set the `:force_build_all` configuration to `true` to have the same effect.\n\nNote that all packages using `RustlerPrecompiled` will be affected by these environment variables.\n\nFor more details about Nerves env vars, see https://hexdocs.pm/nerves/environment-variables.html","ref":"RustlerPrecompiled.html#module-environment-variables"},{"type":"function","title":"RustlerPrecompiled.available_nif_urls/1","doc":"","ref":"RustlerPrecompiled.html#available_nif_urls/1"},{"type":"function","title":"RustlerPrecompiled.available_nifs/1","doc":"Returns URLs for NIFs based on its module name as a list of tuples: `[{lib_name, {url, headers}}]`.\n\nThe module name is the one that defined the NIF and this information\nis stored in a metadata file.","ref":"RustlerPrecompiled.html#available_nifs/1"},{"type":"function","title":"RustlerPrecompiled.current_target_nif_urls/1","doc":"","ref":"RustlerPrecompiled.html#current_target_nif_urls/1"},{"type":"function","title":"RustlerPrecompiled.current_target_nifs/1","doc":"Returns the file URLs to be downloaded for current target as a list of tuples: `[{lib_name, {url, headers}}]`.\n\nIt is in the plural because a target may have some variants for it.\nIt receives the NIF module.","ref":"RustlerPrecompiled.html#current_target_nifs/1"},{"type":"function","title":"RustlerPrecompiled.target/3","doc":"Returns the target triple for download or compile and load.\n\nThis function is translating and adding more info to the system\narchitecture returned by Elixir/Erlang to one used by Rust.\n\nThe returned string has the following format:\n\n    \"nif-NIF_VERSION-ARCHITECTURE-VENDOR-OS-ABI\"","ref":"RustlerPrecompiled.html#target/3"},{"type":"function","title":"Examples - RustlerPrecompiled.target/3","doc":"iex> RustlerPrecompiled.target()\n    {:ok, \"nif-2.16-x86_64-unknown-linux-gnu\"}\n\n    iex> RustlerPrecompiled.target()\n    {:ok, \"nif-2.15-aarch64-apple-darwin\"}","ref":"RustlerPrecompiled.html#target/3-examples"},{"type":"extras","title":"Precompilation guide","doc":"# Precompilation guide\n\nRustler provides an easy way to use safer NIFs in OTP applications. But in some\nenvironments it's harder to use the benefits of the tool because every user\nneeds to install the Rust toolchain and compile the project,\nwhich can take several minutes in some cases.\n\nThis changes with the help of the `RustlerPrecompiled` package. Now we can easily\nuse precompiled Rustler NIFs from an external source.\n\nThe precompilation happens in a CI server, always in a transparent way, and\nthe Hex package published should always include a checksum file to ensure\nthe NIFs stays the same, therefore avoiding supply chain attacks.\n\nIn this guide I will show you how to prepare your project to use this feature.","ref":"precompilation_guide.html"},{"type":"extras","title":"Prepare for the build - Precompilation guide","doc":"Most of the work is done in the CI server. In this example we are going to use GitHub Actions.\n\nThe GH Actions service has the benefit of hosting artifacts for releases and make them\npublic available.","ref":"precompilation_guide.html#prepare-for-the-build"},{"type":"extras","title":"Configure Github Actions - Precompilation guide","doc":"In order for the workflow to succeed, read and write permissions will need to be enabled for the\nrepository.\n\n1. Settings > Actions > General\n2. Workflow permissions\n3. Check the box \"Read and write permissions\"","ref":"precompilation_guide.html#configure-github-actions"},{"type":"extras","title":"Configure Targets - Precompilation guide","doc":"Usually we want to build for the most popular targets and the minimum NIF version supported.\n\nNIF versions are more stable than OTP versions because they usually change only after two major\nreleases of OTP. But older versions are compatible with newer versions if they have the same MAJOR\nnumber. For example, the NIF `2.15` is compatible with `2.16` and `2.17`. So you only need to\ncompile for `2.15` if you want to support these versions. But in case any new feature from the\nnewer versions is needed, then you can build for both versions as well.\n\nIn Rustler - starting from v0.29 -, it's possible to control which version of NIF is active by\nconfiguring cargo features that have this format: `nif_version_MAJOR_MINOR`. So it's possible\nto define features in your project that depends on Rustler features.\nMore details are in the \"Additional configuration before build\".\n\nFor this guide our targets will be the following:\n\n- OS: Linux, Windows, macOS\n- Architectures: `x86_64`, `aarch64` (ARM 64 bits), `arm`\n- NIF versions: `2.15`, `2.16`.\n\nIn summary the build matrix looks like this:\n\n```yaml\nmatrix:\n  nif: [\"2.16\", \"2.15\"]\n  job:\n    - { target: arm-unknown-linux-gnueabihf , os: ubuntu-20.04 , use-cross: true }\n    - { target: aarch64-unknown-linux-gnu   , os: ubuntu-20.04 , use-cross: true }\n    - { target: aarch64-apple-darwin        , os: macos-12      }\n    - { target: x86_64-apple-darwin         , os: macos-12      }\n    - { target: x86_64-unknown-linux-gnu    , os: ubuntu-20.04  }\n    - { target: x86_64-unknown-linux-musl   , os: ubuntu-20.04 , use-cross: true }\n    - { target: x86_64-pc-windows-gnu       , os: windows-2019  }\n    - { target: x86_64-pc-windows-msvc      , os: windows-2019  }\n```\n\nA complete workflow example can be found in the [`rustler_precompilation_example`](https://github.com/philss/rustler_precompilation_example/blob/main/.github/workflows/release.yml) project.\nThat workflow is using a GitHub Action especially made for our goal: [philss/rustler-precompiled-action](https://github.com/philss/rustler-precompiled-action).\nThe GitHub Action will deal with the installation of `cross` and the build of the project, naming the files in the correct format.\n\nSome targets are only supported by later versions of `cross`. For those, you might want to\ninstall `cross` directly from GitHub. You can see an example in [this\npipeline](https://github.com/kloeckner-i/mail_parser/blob/f4af5083aec73a47f0e41a202ba46a91f60602cf/.github/workflows/release.yml#L101-L105).","ref":"precompilation_guide.html#configure-targets"},{"type":"extras","title":"Additional configuration before build - Precompilation guide","doc":"In our build we are going to cross compile our crate project (the Rust code for our NIF) using\na variety of targets, as we saw in the previous section. For this to work we need to guide the Rust\ncompiler in some cases by providing additional configuration in the `.cargo/config` file of our project.\n\nHere is an example of that file:\n\n```toml\n[target.'cfg(target_os = \"macos\")']\nrustflags = [\n  \"-C\", \"link-arg=-undefined\",\n  \"-C\", \"link-arg=dynamic_lookup\",\n]\n\n# See https://github.com/rust-lang/rust/issues/59302\n[target.x86_64-unknown-linux-musl]\nrustflags = [\n  \"-C\", \"target-feature=-crt-static\"\n]\n\n# Provides a small build size, but takes more time to build.\n[profile.release]\nlto = true\n```\n\nIn addition to that, we also use a tool called [`cross`](https://github.com/rust-embedded/cross) that\nmakes the build easier for some targets (the ones using `use-cross: true` in our example).\n\nFor projects using Rustler **before v0.29**, we need to tell `cross` to read an environment variable\nfrom our \"host machine\", because `cross` uses containers to build our software.\n\nSo you need to create the file `Cross.toml` in the NIF directory with the following content:\n\n```toml\n[build.env]\npassthrough = [\n  \"RUSTLER_NIF_VERSION\"\n]\n```\n\n#### Using features to control NIF version in Rustler v0.29 and above\n\nSince Rustler v0.29, it's possible to control which NIF version is active by using cargo features.\nThis is a replacement for the `RUSTLER_NIF_VERSION` env var, that is deprecated in v0.30 of\nRustler.\n\nIf your project does not use anything special from newer NIF versions, then you can declare the\nRustler dependency like this:\n\n```toml\n[dependencies]\nrustler = { version = \"0.29\", default-features = false, features = [\"derive\", \"nif_version_2_15\"] }\n```\n\nAnd in the workflow file, you would specify the `nif-version: 2.15` as usual.\n\nBut in case you want to have newer features from more recent versions of NIF, you can create\nfeatures for your project that are used to activate rustler features. These features should\nfollow the same naming from Rustler, because the CI action is going to use that to activate\nthe right feature.\n\nHere is an example of how your `Cargo.toml` would look like:\n\n```toml\n[dependencies]\nrustler = { version = \"0.29\", default-features = false, features = [\"derive\"] }\n\n# And then, your features.\n[features]\ndefault = [\"nif_version_2_15\"]\nnif_version_2_15 = [\"rustler/nif_version_2_15\"]\nnif_version_2_16 = [\"rustler/nif_version_2_16\"]\nnif_version_2_17 = [\"rustler/nif_version_2_17\"]\n```\n\nIn your code, you would use these features - like `nif_version_2_17` - to control how your\ncode is going to be compiled. You can hide some features behind these features.\nEven if you don't have anything behind these features, you can still introduce them\nif you want to activate an specific NIF version.\n\nBut again, normally it's enough to build for the lowest version supported by the OTP version\nthat you are targeting.\n\nThe available NIF versions are the following:\n\n* `2.14` - for OTP 21 and above.\n* `2.15` - for OTP 22 and above.\n* `2.16` - for OTP 24 and above.\n* `2.17` - for OTP 26 and above.","ref":"precompilation_guide.html#additional-configuration-before-build"},{"type":"extras","title":"The Rustler module - Precompilation guide","doc":"We need to tell `RustlerPrecompiled` where to find our NIF files, and we need to tell which version to use.\n\n```elixir\ndefmodule RustlerPrecompilationExample.Native do\n  version = Mix.Project.config()[:version]\n\n  use RustlerPrecompiled,\n    otp_app: :rustler_precompilation_example,\n    crate: \"example\",\n    base_url:\n      \"https://github.com/philss/rustler_precompilation_example/releases/download/v#{version}\",\n    force_build: System.get_env(\"RUSTLER_PRECOMPILATION_EXAMPLE_BUILD\") in [\"1\", \"true\"],\n    version: version\n\n  # When your NIF is loaded, it will override this function.\n  def add(_a, _b), do: :erlang.nif_error(:nif_not_loaded)\nend\n```\n\nThis example was extracted from the [`rustler_precompilation_example`](https://github.com/philss/rustler_precompilation_example/blob/main/lib/rustler_precompilation_example/native.ex) project.\nRustlerPrecompiled will try to figure out the target and download the correct file for us. This will happen in compile\ntime only.\n\nOptionally it's possible to force the compilation by setting an env var, like the example suggests.\nIt's also possible to force the build by using a pre release version, like `0.1.0-dev`. The only\nrequirement to force the build is to have Rustler declared as a dependency as well:\n`{:rustler, \">= 0.0.0\", optional: true}`.","ref":"precompilation_guide.html#the-rustler-module"},{"type":"extras","title":"The release flow - Precompilation guide","doc":"","ref":"precompilation_guide.html#the-release-flow"},{"type":"extras","title":"Generating a checksum file - Precompilation guide","doc":"In a scenario where you need to release a Hex package using precompiled NIFs, you first need to\nbuild the release in the CI, wait for all artifacts to be available and then generate\nthe **checksum file** that is **MANDATORY** for your package to work.\n\nThis checksum file is generated by running the following command after the build is complete:\n\n    $ mix rustler_precompiled.download YourRustlerModule --all --print\n\nWith the module I used for this guide, the command would be:\n\n    $ mix rustler_precompiled.download RustlerPrecompilationExample.Native --all --print\n\nThe file generated will be named `checksum-Elixir.RustlerPrecompilationExample.Native.exs` and\nit's **extremely important that you include this file in your Hex package** (by updating the `files:`\nfield in your `mix.exs`). Otherwise your package **won't work**. Your `files:` key at your\npackage configuration will look like this:\n\n```elixir\ndefp package do\n  [\n    files: [\n      \"lib\",\n      \"native/example/.cargo\",\n      \"native/example/src\",\n      \"native/example/Cargo*\",\n      \"checksum-*.exs\",\n      \"mix.exs\"\n    ],\n    # ...\n  ]\nend\n```\n\nNote: you don't need to track the checksum file in your version control system (git or other).\n\nFor an example, refer to the `mix.exs` file of the [rustler precompilation example](https://github.com/philss/rustler_precompilation_example/blob/main/mix.exs)\nor elixir-nx's [explorer](https://github.com/elixir-nx/explorer/blob/723eea63204e43bc9238d2488fd355f17a1e13f2/mix.exs#L65-L72) library.\n\nTip: use the `mix hex.build --unpack` command to confirm which files are being included (and if the package looks good before publishing).","ref":"precompilation_guide.html#generating-a-checksum-file"},{"type":"extras","title":"Recommended flow - Precompilation guide","doc":"To recap, the suggested flow is the following:\n\n1. release a new tag\n2. push the code to your repository with the new tag: `git push origin main --tags`\n3. wait for all NIFs to be built\n4. run the `mix rustler_precompiled.download` task (with the flag `--all`)\n5. release the package to Hex.pm (make sure your release includes the correct files).","ref":"precompilation_guide.html#recommended-flow"},{"type":"extras","title":"Conclusion - Precompilation guide","doc":"The ability to use precompiled NIFs written in Rust can increase the adoption of some packages,\nbecause people won't need to have Rust installed. But this comes with some drawbacks and more\nresponsibilities to the maintainers, so use this feature carefully.","ref":"precompilation_guide.html#conclusion"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [0.8.1] - 2024-09-11","ref":"changelog.html"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix return of `available_nifs/1`. It was returning only URLs.\n\n- Fix the \"rustler_precompiled.download\" mix task to use the correct\n  function for the download of artifacts.","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Print SHA256 of artifacts when downloading them from the mix task.\n\n## [0.8.0] - 2024-08-28","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add support for passing headers or a `{module, :function_name}` to `:base_url`.\n  The headers can be passed in the format `{\"URL\", [{\"header_key\", \"header_value\"}]}`.\n  This feature is useful for people that need to perform authentication before downloading\n  the artifacts.\n\n- Add `available_nifs/1` to replace `available_nif_urls/1` that was deprecated.\n  The new function will return a list of tuples in the format: `{\"lib_name\", {\"base_url\", [headers]}}`.\n\n- Add `current_target_nifs/1` to replace `current_target_nif_urls/1` that was deprecated.\n  The new function will return a list of tuples in the format: `{\"lib_name\", {\"base_url\", [headers]}}`.","ref":"changelog.html#added"},{"type":"extras","title":"Deprecated - Changelog","doc":"- `available_nif_urls/1`\n- `current_target_nif_urls/1`","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Remove support for Elixir 1.12.\n\n## [0.7.3] - 2024-08-28","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Add the `alpine` vendor to the list of Linux vendors that we treat as \"unknown\".\n\n## [0.7.2] - 2024-06-26","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- The `RUSTLER_PRECOMPILED_GLOBAL_CACHE_PATH` environment variable was added to enable\n  an easy way to configure a directory to fetch the artifacts before reaching the internet.\n  This is useful to make more predictable where the cache files will be located, thus\n  enabling users to use that directory as a repository for the artifacts.\n  This env var will affect all packages using this library.\n\n - Add the `RUSTLER_PRECOMPILED_FORCE_BUILD_ALL` env var to force the build of all packages\n   using RustlerPrecompiled. Be aware that `Rustler` will be required if this is set\n   to `1` or `true`. There is a new application env that has precedence over the env var,\n   which is the `:force_build_all`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Automatically run the \"app.config\" mix task in the \"rustler_precompiled.download\" mix task.\n\n  This will trigger the project compilation and configuration, but will not start the app.\n  It's necessary to check if the module passed to the task exists or not.\n\n  You can deactivate this behaviour by passing the flag `--no-config` to that mix task.\n  The mix task \"rustler_precompiled.download\" is used in the step of publishing a package.\n\n- Stop throwing an error in case the metadata cannot be written.\n  This is because metadata is only necessary in the process of publishing the package,\n  and users may be running with \"write\" permission restrictions.\n  We now print a warning instead.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Restrict the change of vendor to \"unknown\" only if the target is a Linux system.\n\n## [0.7.1] - 2023-11-30","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix the URL for variants on download.\n\n## [0.7.0] - 2023-09-22","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `:max_retries` option, to control how many times we should try\n  to download a NIF artifact. By default it is going to try 3 times.\n  To disable this feature, use the value `0`.\n\n- Add support for variants. This is a feature that enables building\n  for the same target with multiple configurations. It can support\n  different features or OS dependencies. The selection is done in\n  compile time.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Change default list of NIF versions to only include the version `2.15`.\n  This is because most of the users won't need to activate newer versions,\n  unless they use features from those versions.\n\n  This is going to simplify and speed up the release process for most of the\n  projects.\n\n## [0.6.3] - 2023-08-28","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Make sure `:nif_versions` option is respected.\n\n  This is a small bug fix that was blocking the usage of a more\n  restrict list of \"NIF versions\". For example, if my system is\n  using NIF version 2.16, but I want to be compatible with only\n  version 2.15, this was being ignored, since the algorithm for\n  finding compatible versions was not taking into account this\n  restriction.\n\n## [0.6.2] - 2023-07-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Add support for FreeBSD as a target.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Remove `:crypto` from the extra applications list, because `:ssl` already includes it.\n\n- Update the guide to mention the new way to select a NIF version in Rustler >= 0.29.\n\n## [0.6.1] - 2023-02-16","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Depend on `:ssl` instead of `:public_key` application. Since `:public_key` is started\n  with `:ssl`, this shouldn't break. This change is needed in order to support the upcoming\n  Elixir 1.15.\n\n## [0.6.0] - 2023-01-27","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add support for configuring the NIF versions that the project supports.\n  This can be done with the `:nif_versions` config.\n\n- Add support for `castore` version `~> 1.0`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Add `aarch64-unknown-linux-musl` and `riscv64gc-unknown-linux-gnu` as default targets.\n  The first one is common for people running Linux containers that were built with Musl on Apple computers.\n  The second one is becoming popular for tiny computers, normally running Nerves.\n\n  The adoption of these targets can increase a little bit the compilation time, but\n  can affect a great number of users.\n\n  For package maintainers: please remember to add these targets to your CI workflow.\n  See an example workflow at: https://github.com/philss/rustler_precompilation_example/blob/main/.github/workflows/release.yml\n\n- Change the depth of SSL peer verification to \"3\". This should be more compatible with servers.\n\n- Remove version \"2.14\" from the default NIF versions. Like the change of default targets,\n  this should only have effect in the moment of release of a new package version.\n  Remember to update your workflow file.\n\n## [0.5.5] - 2022-12-10","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Add support for Suse Linux targets. This is a fix to the plataform resolution. Thanks [@fabriziosestito](https://github.com/fabriziosestito).\n- Fix validation of HTTP proxy. This makes the validation similar to the HTTPS proxy. Thanks [@w0rd-driven](https://github.com/w0rd-driven).\n- Map `riscv64` to `riscv64gc` to match Rust naming. Thanks [@fhunleth](https://github.com/fhunleth).\n\n## [0.5.4] - 2022-11-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix building metadata when \"force build\" is enabled and the target is not available.\n\n## [0.5.3] - 2022-10-19","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Always write the metadata file in compilation time, so mix tasks can work smoothly.\n\n## [0.5.2] - 2022-10-03","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix the `target/0` function to use default targets a default argument. This makes the example\n  in the docs work again. Thanks [@jackalcooper](https://github.com/jackalcooper).\n- Only use proxy if it is valid. Thanks [@josevalim](https://github.com/josevalim).\n- Fix the support for PCs running RedHat Linux. Thanks [@Benjamin-Philip](https://github.com/Benjamin-Philip).\n- Improve some points in the docs. Thanks [@whatyouhide](https://github.com/whatyouhide) and [@fabriziosestito](https://github.com/fabriziosestito).\n\n## [0.5.1] - 2022-05-24","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix available targets naming to include the NIF version in the name. It was removed accidentally.\n  Thanks [@adriankumpf](https://github.com/adriankumpf).\n\n## [0.5.0] - 2022-05-24","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Now it's possible to configure the targets list, based in the [Rust's Plataform Support](https://doc.rust-lang.org/stable/rustc/platform-support.html)\n  list. You can run `rustc --print target-list` to get the full list.\n  Thanks [@adriankumpf](https://github.com/adriankumpf).","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- The precompilation guide was improved with instructions and suggestions for the `files` key at\n  the project config.\n  Thanks [@nbw](https://github.com/nbw).\n- Now we raise with a different error if the NIF artifact cannot be written when downloading to create\n  the checksum file.\n\n## [0.4.1] - 2022-04-28","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix `__using__` macro for when Rustler is not loaded.\n\n## [0.4.0] - 2022-04-28","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Make Rustler an optional dependency. This makes installation faster for most of the users.\n\n## [0.3.0] - 2022-03-26","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add the possibility to skip the download of unavailable NIFs when generating the\n  checksum file - thanks [@fahchen](https://github.com/fahchen)\n\n## [0.2.0] - 2022-02-18","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix validation of URL in order to be compatible with Elixir ~> 1.11.\n  The previous implementation was restricted to Elixir ~> 1.13.","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `:force_build` option that fallback to `Rustler`. It passes all options\n  except the ones used by `RustlerPrecompiled` down to `Rustler`.\n  This option will be by default `false`, but if the project is using a pre-release,\n  then it will always be set to `true`.\n  With this change the project starts depending on Rustler.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Relax dependencies to the minor versions.\n\n## [0.1.0] - 2022-02-16","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add basic features to download and use the precompiled NIFs in a safe way.\n\n[Unreleased]: https://github.com/philss/rustler_precompiled/compare/v0.8.1...HEAD\n[0.8.1]: https://github.com/philss/rustler_precompiled/compare/v0.8.0...v0.8.1\n[0.8.0]: https://github.com/philss/rustler_precompiled/compare/v0.7.3...v0.8.0\n[0.7.3]: https://github.com/philss/rustler_precompiled/compare/v0.7.2...v0.7.3\n[0.7.2]: https://github.com/philss/rustler_precompiled/compare/v0.7.1...v0.7.2\n[0.7.1]: https://github.com/philss/rustler_precompiled/compare/v0.7.0...v0.7.1\n[0.7.0]: https://github.com/philss/rustler_precompiled/compare/v0.6.3...v0.7.0\n[0.6.3]: https://github.com/philss/rustler_precompiled/compare/v0.6.2...v0.6.3\n[0.6.2]: https://github.com/philss/rustler_precompiled/compare/v0.6.1...v0.6.2\n[0.6.1]: https://github.com/philss/rustler_precompiled/compare/v0.6.0...v0.6.1\n[0.6.0]: https://github.com/philss/rustler_precompiled/compare/v0.5.5...v0.6.0\n[0.5.5]: https://github.com/philss/rustler_precompiled/compare/v0.5.4...v0.5.5\n[0.5.4]: https://github.com/philss/rustler_precompiled/compare/v0.5.3...v0.5.4\n[0.5.3]: https://github.com/philss/rustler_precompiled/compare/v0.5.2...v0.5.3\n[0.5.2]: https://github.com/philss/rustler_precompiled/compare/v0.5.1...v0.5.2\n[0.5.1]: https://github.com/philss/rustler_precompiled/compare/v0.5.0...v0.5.1\n[0.5.0]: https://github.com/philss/rustler_precompiled/compare/v0.4.1...v0.5.0\n[0.4.1]: https://github.com/philss/rustler_precompiled/compare/v0.4.0...v0.4.1\n[0.4.0]: https://github.com/philss/rustler_precompiled/compare/v0.3.0...v0.4.0\n[0.3.0]: https://github.com/philss/rustler_precompiled/compare/v0.2.0...v0.3.0\n[0.2.0]: https://github.com/philss/rustler_precompiled/compare/v0.1.0...v0.2.0\n[0.1.0]: https://github.com/philss/rustler_precompiled/releases/tag/v0.1.0","ref":"changelog.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}